import ctypes

def containsAll(str, set):
    """Check whether 'str' contains ALL of the chars in 'set'"""
    return 0 not in [c in str for c in set]

def transfExtents(in_extDetails):
    theProj = Proj(in_extDetails[1])
    thePts = [float(s) for s in in_extDetails[2].split(',')]
    ptsObj = [Point(thePts[0],thePts[1]), Point(thePts[2],thePts[3])]
    pts = theProj.transf(ptsObj)
    retStr = ''
    for thepoint in pts:
        if (len(retStr) > 0):
            retStr += ','
        retStr += str(thepoint.x) +',' + str(thepoint.y)
    return retStr

class Point:
    def __init__(self, x, y):
        self.x = x
        self.y = y
    def __str__(self):
        return 'x : ' + str(self.x) + ' y : ' + str(self.y)

class Proj:
    def __init__(self, input_projcs_str):
        self.pe = ctypes.windll.pe
        self.source_projcs = self.pe.pe_projcs_from_string(input_projcs_str)
        custom_geotran_str = 'GEOGTRAN[ METHOD["Molodensky"],PARAMETER["X_Axis_Translation",0.0],PARAMETER["Y_Axis_Translation",0.0],PARAMETER["Z_Axis_Translation",0.0]]';
        self.transform = self.pe.pe_geogtran_from_string(custom_geotran_str)
        self.point_type = ctypes.c_double * 2

    def _points_to_ctypes(self, points):
        array_type = ctypes.ARRAY(self.point_type, len(points))
        ctype_points = []
        for point in points:
            ctype_point = self.point_type(point.x, point.y)
            ctype_points.append(ctype_point)
        return array_type(*ctype_points)

    def _ctypes_to_points(self, point_array):
        points = []
        for point in point_array:
            point = Point(point[0], point[1])
            points.append(point)
        return points

    def transf(self, points):
        #return points
        #points = [Point(12482.4728892747, 3411157.06227483), Point(-23112.5110711093, 3364166.5618667)]
        points_count = len(points)
        point_array = self._points_to_ctypes(points)
        self.pe.pe_proj_to_geog(self.source_projcs,points_count,point_array)                
        self.pe.pe_geog1_to_geog2(self.transform, points_count, point_array, None)
        return self._ctypes_to_points(point_array)

  
